# scorejapangarbage
The amount of household garbage generated by each prefecture in Japan was divided by the population, and a score was assigned.

# How to install and run scorejapangarbage
<pre>
$ pip install scorejapangarbage

$ scorejapangarbage
</pre>
